******************************************************************************* 
*
* This script draws labels for the longitudes and latitudes of a moving nest 
* with the grid dimensions provided by the file basic_std.txt in the format: 
* 
* 2005082600    0  0  2   301  241  28.2600  23.4600  -82.9110  -76.9110  ... 
* 2005082600   24  0  2   301  241  28.0200  23.2200  -86.2310  -80.2310  ... 
* 2005082600   48  0  2   301  241  27.8400  23.0400  -89.9510  -83.9510  ... 
* 
* USAGE: latlonlabs  file    ntime   <idlon>  <xloc>  <yloc> 
*           <xwest> <xeast> <ysouth> <ynorth> <ifont> <asize> <icolor> 
* 
*        file   = data filename 
*        ntime  = time step (number of record in the file)  
*        idlon  = label resolution for  both lat and lon [integer degrees]  
*        xloc   = x-location in virtual page for latitude  labels [inch] 
*        yloc   = y-location in virtual page for longitude labels [inch] 
*        xwest  = west  boundary of plotting area in virtual page [inch] 
*        xeast  = east  boundary of plotting area in virtual page [inch] 
*        ysouth = south boundary of plotting area in virtual page [inch] 
*        ynorth = north boundary of plotting area in virtual page [inch] 
*        ifont  = number for the font  of the lat-lon lables [GrADS] 
*        asize  = size of the letters for the lat-lon lables [inch] 
*        icolor = number for the color of the lat-lon lables [GrADS] 
*        <****> = optional argument 
* 
*------------------------------------------------------------------------------ 

FUNCTION latlon(args)

file   = subwrd(args,1)
ntime  = subwrd(args,2)
idlon  = subwrd(args,3)
xloc   = subwrd(args,4)
yloc   = subwrd(args,5)
xwest  = subwrd(args,6)
xeast  = subwrd(args,7)
ysouth = subwrd(args,8)
ynorth = subwrd(args,9)
ifont  = subwrd(args,10)
asize  = subwrd(args,11)
icolor = subwrd(args,12)

IF ( idlon  = ''  ) ; idlon  =   1  ; ENDIF
IF ( xloc   = ''  ) ; xloc   = 1.48 ; ENDIF
IF ( yloc   = ''  ) ; yloc   = 0.60 ; ENDIF
IF ( xwest  = ''  ) ; xwest  = 1.70 ; ENDIF
IF ( xeast  = ''  ) ; xeast  = 9.30 ; ENDIF
IF ( ysouth = ''  ) ; ysouth = 0.75 ; ENDIF
IF ( ynorth = ''  ) ; ynorth = 7.75 ; ENDIF
IF ( ifont  = ''  ) ; ifont  =   4  ; ENDIF
IF ( asize  = ''  ) ; asize  = 0.11 ; ENDIF
IF ( icolor = ''  ) ; icolor =   1  ; ENDIF
inorth = 7 ; isouth = 8 ; iwest = 9 ; ieast = 10 
jdlat  = idlon 

'set font   'ifont
'set strsiz 'asize*5/6' 'asize
'set string 'icolor' c'
'set line   'icolor' 1 1'

n = 1 
WHILE ( n <= ntime )

  reading =  read(file)
  record = sublin(reading,2)
   blat  = subwrd(record,inorth)
   alat  = subwrd(record,isouth)
   alon  = subwrd(record,iwest)
   blon  = subwrd(record,ieast)

   IF ( n = ntime )
     
      IF ( alon = math_int(alon) ) 
         istart = math_int(alon) 
      ELSE 
         istart = math_int(alon) + 1 
      ENDIF 
      imod = math_mod(istart,idlon) 
    istart = istart + math_mod(idlon-imod,idlon) 
      iend = math_int(blon) ; imod = math_mod(iend,idlon) 
      iend =  iend  - math_mod(idlon+imod,idlon) 
     xrate = (xeast-xwest)/(blon-alon) ; dx = idlon*xrate 
     
      i = istart ; ii = istart - idlon 
      xold = xwest + (ii-alon)*xrate ; yold = yloc 
      WHILE ( i <= iend )
         IF ( i - ii = idlon )
            xnew = xold + dx ; ynew = yloc 
            xxx1 = xnew ; yyy1 = ysouth 
            xxx2 = xnew ; yyy2 = ysouth - 0.04 
                           'draw  line  'xxx1' 'yyy1' 'xxx2' 'yyy2 
            IF ( i < 0 ) ; 'draw string 'xnew' 'ynew' 'math_abs(i)'W' 
                  ELSE   ; 'draw string 'xnew' 'ynew' 'math_abs(i)'E' ; ENDIF
            ii = i ; xold = xnew ; yold = ynew 
         ENDIF
         i = i + 1 
      ENDWHILE 
     
      IF ( alat = math_int(alat) ) 
         jstart = math_int(alat) 
      ELSE 
         jstart = math_int(alat) + 1 
      ENDIF 
      jmod = math_mod(jstart,jdlat) 
    jstart = jstart + math_mod(jdlat-jmod,jdlat) 
      jend = math_int(blat) ; jmod = math_mod(jend,jdlat) 
      jend =  jend  - math_mod(jdlat+jmod,jdlat) 
     yrate = (ynorth-ysouth)/(blat-alat) ; dy = jdlat*yrate 
     
      j = jstart ; jj = jstart - jdlat 
      xold = xloc ; yold = ysouth + (jj-alat)*yrate 
      WHILE ( j <= jend )
         IF ( j - jj = jdlat )
            xnew = xloc  ;  ynew = yold + dy 
            xxx1 = xwest ;  yyy1 = ynew 
            xxx2 = xwest - 0.05 ; yyy2 = ynew 
                           'draw  line  'xxx1' 'yyy1' 'xxx2' 'yyy2 
            IF ( j < 0 ) ; 'draw string 'xnew' 'ynew' 'math_abs(j)'S' ; ENDIF 
            IF ( j > 0 ) ; 'draw string 'xnew' 'ynew' 'math_abs(j)'N' ; ENDIF 
            IF ( j = 0 ) ; 'draw string 'xnew' 'ynew'  EQ' ; ENDIF
            jj = j ; xold = xnew ; yold = ynew 
         ENDIF
         j = j + 1 
      ENDWHILE 
     
   ENDIF

   n = n + 1 

ENDWHILE 

RETURN

*============================================================================== 
